# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class PassCriteria(Base):
	"""The PassCriteria class encapsulates a required passCriteria node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the PassCriteria property from a parent instance.
	The internal properties list will contain one and only one set of properties which is populated when the property is accessed.
	"""

	_SDM_NAME = 'passCriteria'

	def __init__(self, parent):
		super(PassCriteria, self).__init__(parent)

	@property
	def DownstreamDataErrorThresholdMode(self):
		"""Signifies threshold mode for downstream data error.

		Returns:
			str(average|maximum)
		"""
		return self._get_attribute('downstreamDataErrorThresholdMode')
	@DownstreamDataErrorThresholdMode.setter
	def DownstreamDataErrorThresholdMode(self, value):
		self._set_attribute('downstreamDataErrorThresholdMode', value)

	@property
	def DownstreamDataErrorThresholdValue(self):
		"""Signifies the downstream data error threshold value.

		Returns:
			number
		"""
		return self._get_attribute('downstreamDataErrorThresholdValue')
	@DownstreamDataErrorThresholdValue.setter
	def DownstreamDataErrorThresholdValue(self, value):
		self._set_attribute('downstreamDataErrorThresholdValue', value)

	@property
	def DownstreamEnableDataIntegrityPassFail(self):
		"""if true, enables pass or faill of data integrity for downstream.

		Returns:
			bool
		"""
		return self._get_attribute('downstreamEnableDataIntegrityPassFail')
	@DownstreamEnableDataIntegrityPassFail.setter
	def DownstreamEnableDataIntegrityPassFail(self, value):
		self._set_attribute('downstreamEnableDataIntegrityPassFail', value)

	@property
	def DownstreamEnableLatencyPassFail(self):
		"""If true, enables latency pass fail for downstream.

		Returns:
			bool
		"""
		return self._get_attribute('downstreamEnableLatencyPassFail')
	@DownstreamEnableLatencyPassFail.setter
	def DownstreamEnableLatencyPassFail(self, value):
		self._set_attribute('downstreamEnableLatencyPassFail', value)

	@property
	def DownstreamEnableRatePassFail(self):
		"""If true, enables pass fail rate for downstream.

		Returns:
			bool
		"""
		return self._get_attribute('downstreamEnableRatePassFail')
	@DownstreamEnableRatePassFail.setter
	def DownstreamEnableRatePassFail(self, value):
		self._set_attribute('downstreamEnableRatePassFail', value)

	@property
	def DownstreamEnableSequenceErrorsPassFail(self):
		"""If true, enables the pass fail for sequence errors for downstream.

		Returns:
			bool
		"""
		return self._get_attribute('downstreamEnableSequenceErrorsPassFail')
	@DownstreamEnableSequenceErrorsPassFail.setter
	def DownstreamEnableSequenceErrorsPassFail(self, value):
		self._set_attribute('downstreamEnableSequenceErrorsPassFail', value)

	@property
	def DownstreamEnableStandardDeviationPassFail(self):
		"""If true, enables pass fail of standard deviation for downstream.

		Returns:
			bool
		"""
		return self._get_attribute('downstreamEnableStandardDeviationPassFail')
	@DownstreamEnableStandardDeviationPassFail.setter
	def DownstreamEnableStandardDeviationPassFail(self, value):
		self._set_attribute('downstreamEnableStandardDeviationPassFail', value)

	@property
	def DownstreamLatencyThresholdMode(self):
		"""Signifies the latency threshold mode for downstream.

		Returns:
			str(average|maximum)
		"""
		return self._get_attribute('downstreamLatencyThresholdMode')
	@DownstreamLatencyThresholdMode.setter
	def DownstreamLatencyThresholdMode(self, value):
		self._set_attribute('downstreamLatencyThresholdMode', value)

	@property
	def DownstreamLatencyThresholdScale(self):
		"""Signifies the threshold scale for downstream latency.

		Returns:
			str(ms|ns|us)
		"""
		return self._get_attribute('downstreamLatencyThresholdScale')
	@DownstreamLatencyThresholdScale.setter
	def DownstreamLatencyThresholdScale(self, value):
		self._set_attribute('downstreamLatencyThresholdScale', value)

	@property
	def DownstreamLatencyThresholdValue(self):
		"""Signifies the latency threshold value for downstream.

		Returns:
			number
		"""
		return self._get_attribute('downstreamLatencyThresholdValue')
	@DownstreamLatencyThresholdValue.setter
	def DownstreamLatencyThresholdValue(self, value):
		self._set_attribute('downstreamLatencyThresholdValue', value)

	@property
	def DownstreamLatencyVarThresholdMode(self):
		"""Signifies latency variation threshold mode for downstream.

		Returns:
			str(average|maximum)
		"""
		return self._get_attribute('downstreamLatencyVarThresholdMode')
	@DownstreamLatencyVarThresholdMode.setter
	def DownstreamLatencyVarThresholdMode(self, value):
		self._set_attribute('downstreamLatencyVarThresholdMode', value)

	@property
	def DownstreamLatencyVariationThresholdScale(self):
		"""Signifies latency variation threshold scale for downstream.

		Returns:
			str(ms|ns|us)
		"""
		return self._get_attribute('downstreamLatencyVariationThresholdScale')
	@DownstreamLatencyVariationThresholdScale.setter
	def DownstreamLatencyVariationThresholdScale(self, value):
		self._set_attribute('downstreamLatencyVariationThresholdScale', value)

	@property
	def DownstreamLatencyVariationThresholdValue(self):
		"""Signifies the latency variation threshold value for downstream.

		Returns:
			number
		"""
		return self._get_attribute('downstreamLatencyVariationThresholdValue')
	@DownstreamLatencyVariationThresholdValue.setter
	def DownstreamLatencyVariationThresholdValue(self, value):
		self._set_attribute('downstreamLatencyVariationThresholdValue', value)

	@property
	def DownstreamPassCriteriaLoadRateMode(self):
		"""Signifies the pass criteria load rate mode for downstream.

		Returns:
			str(average|minimum)
		"""
		return self._get_attribute('downstreamPassCriteriaLoadRateMode')
	@DownstreamPassCriteriaLoadRateMode.setter
	def DownstreamPassCriteriaLoadRateMode(self, value):
		self._set_attribute('downstreamPassCriteriaLoadRateMode', value)

	@property
	def DownstreamPassCriteriaLoadRateScale(self):
		"""Signifies the pass criteria load rate scale for downstream.

		Returns:
			str(fps|gbps|kbps|mbps|percent)
		"""
		return self._get_attribute('downstreamPassCriteriaLoadRateScale')
	@DownstreamPassCriteriaLoadRateScale.setter
	def DownstreamPassCriteriaLoadRateScale(self, value):
		self._set_attribute('downstreamPassCriteriaLoadRateScale', value)

	@property
	def DownstreamPassCriteriaLoadRateValue(self):
		"""Signifies pass criteria load rate value for downstream.

		Returns:
			number
		"""
		return self._get_attribute('downstreamPassCriteriaLoadRateValue')
	@DownstreamPassCriteriaLoadRateValue.setter
	def DownstreamPassCriteriaLoadRateValue(self, value):
		self._set_attribute('downstreamPassCriteriaLoadRateValue', value)

	@property
	def DownstreamSeqErrorsThresholdMode(self):
		"""Signifies the threshold mode for sequence errors for downstream.

		Returns:
			str(average|maximum)
		"""
		return self._get_attribute('downstreamSeqErrorsThresholdMode')
	@DownstreamSeqErrorsThresholdMode.setter
	def DownstreamSeqErrorsThresholdMode(self, value):
		self._set_attribute('downstreamSeqErrorsThresholdMode', value)

	@property
	def DownstreamSeqErrorsThresholdValue(self):
		"""Signifies the threshold value for sequence errors for downstream.

		Returns:
			number
		"""
		return self._get_attribute('downstreamSeqErrorsThresholdValue')
	@DownstreamSeqErrorsThresholdValue.setter
	def DownstreamSeqErrorsThresholdValue(self, value):
		self._set_attribute('downstreamSeqErrorsThresholdValue', value)

	@property
	def Downstream_passFailFrequency(self):
		"""NOT DEFINED

		Returns:
			str(framesizes|trials)
		"""
		return self._get_attribute('downstream_passFailFrequency')
	@Downstream_passFailFrequency.setter
	def Downstream_passFailFrequency(self, value):
		self._set_attribute('downstream_passFailFrequency', value)

	@property
	def UpstreamDataErrorThresholdMode(self):
		"""Signifies the data error threshold mode for upstream.

		Returns:
			str(average|maximum)
		"""
		return self._get_attribute('upstreamDataErrorThresholdMode')
	@UpstreamDataErrorThresholdMode.setter
	def UpstreamDataErrorThresholdMode(self, value):
		self._set_attribute('upstreamDataErrorThresholdMode', value)

	@property
	def UpstreamDataErrorThresholdValue(self):
		"""Signifies data error threshold value for upstream.

		Returns:
			number
		"""
		return self._get_attribute('upstreamDataErrorThresholdValue')
	@UpstreamDataErrorThresholdValue.setter
	def UpstreamDataErrorThresholdValue(self, value):
		self._set_attribute('upstreamDataErrorThresholdValue', value)

	@property
	def UpstreamEnableDataIntegrityPassFail(self):
		"""If true, enables pass fail of data integrity for upstream.

		Returns:
			bool
		"""
		return self._get_attribute('upstreamEnableDataIntegrityPassFail')
	@UpstreamEnableDataIntegrityPassFail.setter
	def UpstreamEnableDataIntegrityPassFail(self, value):
		self._set_attribute('upstreamEnableDataIntegrityPassFail', value)

	@property
	def UpstreamEnableLatencyPassFail(self):
		"""If true, enables latency pass fail for upstream.

		Returns:
			bool
		"""
		return self._get_attribute('upstreamEnableLatencyPassFail')
	@UpstreamEnableLatencyPassFail.setter
	def UpstreamEnableLatencyPassFail(self, value):
		self._set_attribute('upstreamEnableLatencyPassFail', value)

	@property
	def UpstreamEnableRatePassFail(self):
		"""If true, enables the rate of pass fail for upstream.

		Returns:
			bool
		"""
		return self._get_attribute('upstreamEnableRatePassFail')
	@UpstreamEnableRatePassFail.setter
	def UpstreamEnableRatePassFail(self, value):
		self._set_attribute('upstreamEnableRatePassFail', value)

	@property
	def UpstreamEnableSequenceErrorsPassFail(self):
		"""If true, enables sequence errors pass fail for upstream.

		Returns:
			bool
		"""
		return self._get_attribute('upstreamEnableSequenceErrorsPassFail')
	@UpstreamEnableSequenceErrorsPassFail.setter
	def UpstreamEnableSequenceErrorsPassFail(self, value):
		self._set_attribute('upstreamEnableSequenceErrorsPassFail', value)

	@property
	def UpstreamEnableStandardDeviationPassFail(self):
		"""If true, enables standard deviation of pass and fail for upstream.

		Returns:
			bool
		"""
		return self._get_attribute('upstreamEnableStandardDeviationPassFail')
	@UpstreamEnableStandardDeviationPassFail.setter
	def UpstreamEnableStandardDeviationPassFail(self, value):
		self._set_attribute('upstreamEnableStandardDeviationPassFail', value)

	@property
	def UpstreamLatencyThresholdMode(self):
		"""Signifies the latency threshold mode for upstream.

		Returns:
			str(average|maximum)
		"""
		return self._get_attribute('upstreamLatencyThresholdMode')
	@UpstreamLatencyThresholdMode.setter
	def UpstreamLatencyThresholdMode(self, value):
		self._set_attribute('upstreamLatencyThresholdMode', value)

	@property
	def UpstreamLatencyThresholdScale(self):
		"""Signifies the latency threshold scale for upstream.

		Returns:
			str(ms|ns|us)
		"""
		return self._get_attribute('upstreamLatencyThresholdScale')
	@UpstreamLatencyThresholdScale.setter
	def UpstreamLatencyThresholdScale(self, value):
		self._set_attribute('upstreamLatencyThresholdScale', value)

	@property
	def UpstreamLatencyThresholdValue(self):
		"""It is the latency threshold value for upstream.

		Returns:
			number
		"""
		return self._get_attribute('upstreamLatencyThresholdValue')
	@UpstreamLatencyThresholdValue.setter
	def UpstreamLatencyThresholdValue(self, value):
		self._set_attribute('upstreamLatencyThresholdValue', value)

	@property
	def UpstreamLatencyVarThresholdMode(self):
		"""Signifies the latency variation threshold mode for upstream.

		Returns:
			str(average|maximum)
		"""
		return self._get_attribute('upstreamLatencyVarThresholdMode')
	@UpstreamLatencyVarThresholdMode.setter
	def UpstreamLatencyVarThresholdMode(self, value):
		self._set_attribute('upstreamLatencyVarThresholdMode', value)

	@property
	def UpstreamLatencyVariationThresholdScale(self):
		"""It is the latency variation threshold scale for upstream.

		Returns:
			str(ms|ns|us)
		"""
		return self._get_attribute('upstreamLatencyVariationThresholdScale')
	@UpstreamLatencyVariationThresholdScale.setter
	def UpstreamLatencyVariationThresholdScale(self, value):
		self._set_attribute('upstreamLatencyVariationThresholdScale', value)

	@property
	def UpstreamLatencyVariationThresholdValue(self):
		"""Signifies the latency variation threshold value for upstream.

		Returns:
			number
		"""
		return self._get_attribute('upstreamLatencyVariationThresholdValue')
	@UpstreamLatencyVariationThresholdValue.setter
	def UpstreamLatencyVariationThresholdValue(self, value):
		self._set_attribute('upstreamLatencyVariationThresholdValue', value)

	@property
	def UpstreamPassCriteriaLoadRateMode(self):
		"""Signifies the pass criteria load rate mode for upstream.

		Returns:
			str(average|minimum)
		"""
		return self._get_attribute('upstreamPassCriteriaLoadRateMode')
	@UpstreamPassCriteriaLoadRateMode.setter
	def UpstreamPassCriteriaLoadRateMode(self, value):
		self._set_attribute('upstreamPassCriteriaLoadRateMode', value)

	@property
	def UpstreamPassCriteriaLoadRateScale(self):
		"""Signifies pass criteria for load rate scale for upstream.

		Returns:
			str(fps|gbps|kbps|mbps|percent)
		"""
		return self._get_attribute('upstreamPassCriteriaLoadRateScale')
	@UpstreamPassCriteriaLoadRateScale.setter
	def UpstreamPassCriteriaLoadRateScale(self, value):
		self._set_attribute('upstreamPassCriteriaLoadRateScale', value)

	@property
	def UpstreamPassCriteriaLoadRateValue(self):
		"""Signifies the pass criteria load rate value for upstream.

		Returns:
			number
		"""
		return self._get_attribute('upstreamPassCriteriaLoadRateValue')
	@UpstreamPassCriteriaLoadRateValue.setter
	def UpstreamPassCriteriaLoadRateValue(self, value):
		self._set_attribute('upstreamPassCriteriaLoadRateValue', value)

	@property
	def UpstreamSeqErrorsThresholdMode(self):
		"""Signifies the sequence errors threshold mode for upstream.

		Returns:
			str(average|maximum)
		"""
		return self._get_attribute('upstreamSeqErrorsThresholdMode')
	@UpstreamSeqErrorsThresholdMode.setter
	def UpstreamSeqErrorsThresholdMode(self, value):
		self._set_attribute('upstreamSeqErrorsThresholdMode', value)

	@property
	def UpstreamSeqErrorsThresholdValue(self):
		"""Signifies sequence errors threshold value for upstream.

		Returns:
			number
		"""
		return self._get_attribute('upstreamSeqErrorsThresholdValue')
	@UpstreamSeqErrorsThresholdValue.setter
	def UpstreamSeqErrorsThresholdValue(self, value):
		self._set_attribute('upstreamSeqErrorsThresholdValue', value)

	@property
	def Upstream_passFailFrequency(self):
		"""NOT DEFINED

		Returns:
			str(framesizes|trials)
		"""
		return self._get_attribute('upstream_passFailFrequency')
	@Upstream_passFailFrequency.setter
	def Upstream_passFailFrequency(self, value):
		self._set_attribute('upstream_passFailFrequency', value)

	def update(self, DownstreamDataErrorThresholdMode=None, DownstreamDataErrorThresholdValue=None, DownstreamEnableDataIntegrityPassFail=None, DownstreamEnableLatencyPassFail=None, DownstreamEnableRatePassFail=None, DownstreamEnableSequenceErrorsPassFail=None, DownstreamEnableStandardDeviationPassFail=None, DownstreamLatencyThresholdMode=None, DownstreamLatencyThresholdScale=None, DownstreamLatencyThresholdValue=None, DownstreamLatencyVarThresholdMode=None, DownstreamLatencyVariationThresholdScale=None, DownstreamLatencyVariationThresholdValue=None, DownstreamPassCriteriaLoadRateMode=None, DownstreamPassCriteriaLoadRateScale=None, DownstreamPassCriteriaLoadRateValue=None, DownstreamSeqErrorsThresholdMode=None, DownstreamSeqErrorsThresholdValue=None, Downstream_passFailFrequency=None, UpstreamDataErrorThresholdMode=None, UpstreamDataErrorThresholdValue=None, UpstreamEnableDataIntegrityPassFail=None, UpstreamEnableLatencyPassFail=None, UpstreamEnableRatePassFail=None, UpstreamEnableSequenceErrorsPassFail=None, UpstreamEnableStandardDeviationPassFail=None, UpstreamLatencyThresholdMode=None, UpstreamLatencyThresholdScale=None, UpstreamLatencyThresholdValue=None, UpstreamLatencyVarThresholdMode=None, UpstreamLatencyVariationThresholdScale=None, UpstreamLatencyVariationThresholdValue=None, UpstreamPassCriteriaLoadRateMode=None, UpstreamPassCriteriaLoadRateScale=None, UpstreamPassCriteriaLoadRateValue=None, UpstreamSeqErrorsThresholdMode=None, UpstreamSeqErrorsThresholdValue=None, Upstream_passFailFrequency=None):
		"""Updates a child instance of passCriteria on the server.

		Args:
			DownstreamDataErrorThresholdMode (str(average|maximum)): Signifies threshold mode for downstream data error.
			DownstreamDataErrorThresholdValue (number): Signifies the downstream data error threshold value.
			DownstreamEnableDataIntegrityPassFail (bool): if true, enables pass or faill of data integrity for downstream.
			DownstreamEnableLatencyPassFail (bool): If true, enables latency pass fail for downstream.
			DownstreamEnableRatePassFail (bool): If true, enables pass fail rate for downstream.
			DownstreamEnableSequenceErrorsPassFail (bool): If true, enables the pass fail for sequence errors for downstream.
			DownstreamEnableStandardDeviationPassFail (bool): If true, enables pass fail of standard deviation for downstream.
			DownstreamLatencyThresholdMode (str(average|maximum)): Signifies the latency threshold mode for downstream.
			DownstreamLatencyThresholdScale (str(ms|ns|us)): Signifies the threshold scale for downstream latency.
			DownstreamLatencyThresholdValue (number): Signifies the latency threshold value for downstream.
			DownstreamLatencyVarThresholdMode (str(average|maximum)): Signifies latency variation threshold mode for downstream.
			DownstreamLatencyVariationThresholdScale (str(ms|ns|us)): Signifies latency variation threshold scale for downstream.
			DownstreamLatencyVariationThresholdValue (number): Signifies the latency variation threshold value for downstream.
			DownstreamPassCriteriaLoadRateMode (str(average|minimum)): Signifies the pass criteria load rate mode for downstream.
			DownstreamPassCriteriaLoadRateScale (str(fps|gbps|kbps|mbps|percent)): Signifies the pass criteria load rate scale for downstream.
			DownstreamPassCriteriaLoadRateValue (number): Signifies pass criteria load rate value for downstream.
			DownstreamSeqErrorsThresholdMode (str(average|maximum)): Signifies the threshold mode for sequence errors for downstream.
			DownstreamSeqErrorsThresholdValue (number): Signifies the threshold value for sequence errors for downstream.
			Downstream_passFailFrequency (str(framesizes|trials)): NOT DEFINED
			UpstreamDataErrorThresholdMode (str(average|maximum)): Signifies the data error threshold mode for upstream.
			UpstreamDataErrorThresholdValue (number): Signifies data error threshold value for upstream.
			UpstreamEnableDataIntegrityPassFail (bool): If true, enables pass fail of data integrity for upstream.
			UpstreamEnableLatencyPassFail (bool): If true, enables latency pass fail for upstream.
			UpstreamEnableRatePassFail (bool): If true, enables the rate of pass fail for upstream.
			UpstreamEnableSequenceErrorsPassFail (bool): If true, enables sequence errors pass fail for upstream.
			UpstreamEnableStandardDeviationPassFail (bool): If true, enables standard deviation of pass and fail for upstream.
			UpstreamLatencyThresholdMode (str(average|maximum)): Signifies the latency threshold mode for upstream.
			UpstreamLatencyThresholdScale (str(ms|ns|us)): Signifies the latency threshold scale for upstream.
			UpstreamLatencyThresholdValue (number): It is the latency threshold value for upstream.
			UpstreamLatencyVarThresholdMode (str(average|maximum)): Signifies the latency variation threshold mode for upstream.
			UpstreamLatencyVariationThresholdScale (str(ms|ns|us)): It is the latency variation threshold scale for upstream.
			UpstreamLatencyVariationThresholdValue (number): Signifies the latency variation threshold value for upstream.
			UpstreamPassCriteriaLoadRateMode (str(average|minimum)): Signifies the pass criteria load rate mode for upstream.
			UpstreamPassCriteriaLoadRateScale (str(fps|gbps|kbps|mbps|percent)): Signifies pass criteria for load rate scale for upstream.
			UpstreamPassCriteriaLoadRateValue (number): Signifies the pass criteria load rate value for upstream.
			UpstreamSeqErrorsThresholdMode (str(average|maximum)): Signifies the sequence errors threshold mode for upstream.
			UpstreamSeqErrorsThresholdValue (number): Signifies sequence errors threshold value for upstream.
			Upstream_passFailFrequency (str(framesizes|trials)): NOT DEFINED

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def Apply(self):
		"""Executes the apply operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('apply', payload=payload, response_object=None)

	def ApplyAsync(self):
		"""Executes the applyAsync operation on the server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsync', payload=payload, response_object=None)

	def ApplyAsyncResult(self):
		"""Executes the applyAsyncResult operation on the server.

			Returns:
				bool: 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyAsyncResult', payload=payload, response_object=None)

	def ApplyITWizardConfiguration(self):
		"""Executes the applyITWizardConfiguration operation on the server.

		Applies the specified Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('applyITWizardConfiguration', payload=payload, response_object=None)

	def GenerateReport(self):
		"""Executes the generateReport operation on the server.

		Generate a PDF report for the last succesfull test run.

			Returns:
				str: This method is asynchronous and has no return value.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('generateReport', payload=payload, response_object=None)

	def Run(self, *args, **kwargs):
		"""Executes the run operation on the server.

		Starts the specified Quick Test and waits for its execution to finish.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		run()list

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		run(InputParameters:string)list
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('run', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Starts the specified Quick Test.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(InputParameters:string)
			Args:
				args[0] is InputParameters (str): The input arguments of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self):
		"""Executes the stop operation on the server.

		Stops the currently running Quick Test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('stop', payload=payload, response_object=None)

	def WaitForTest(self):
		"""Executes the waitForTest operation on the server.

		Waits for the execution of the specified Quick Test to be completed.

			Returns:
				list(str): This method is synchronous and returns the result of the test.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		return self._execute('waitForTest', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class CustomTopology(Base):
	"""The CustomTopology class encapsulates a user managed customTopology node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the CustomTopology property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'customTopology'

	def __init__(self, parent):
		super(CustomTopology, self).__init__(parent)

	@property
	def CustomTopologyMulticastIpv4GroupRange(self):
		"""An instance of the CustomTopologyMulticastIpv4GroupRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.customtopologymulticastipv4grouprange.CustomTopologyMulticastIpv4GroupRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.customtopologymulticastipv4grouprange import CustomTopologyMulticastIpv4GroupRange
		return CustomTopologyMulticastIpv4GroupRange(self)

	@property
	def CustomTopologyMulticastIpv6GroupRange(self):
		"""An instance of the CustomTopologyMulticastIpv6GroupRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.customtopologymulticastipv6grouprange.CustomTopologyMulticastIpv6GroupRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.customtopologymulticastipv6grouprange import CustomTopologyMulticastIpv6GroupRange
		return CustomTopologyMulticastIpv6GroupRange(self)

	@property
	def CustomTopologyMulticastMacRange(self):
		"""An instance of the CustomTopologyMulticastMacRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.customtopologymulticastmacrange.CustomTopologyMulticastMacRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.customtopologymulticastmacrange import CustomTopologyMulticastMacRange
		return CustomTopologyMulticastMacRange(self)

	@property
	def CustomTopologyNode(self):
		"""An instance of the CustomTopologyNode class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.customtopologynode.CustomTopologyNode)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.customtopologynode import CustomTopologyNode
		return CustomTopologyNode(self)

	@property
	def CustomTopologyNodeTopologyRange(self):
		"""An instance of the CustomTopologyNodeTopologyRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.customtopologynodetopologyrange.CustomTopologyNodeTopologyRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.customtopologynodetopologyrange import CustomTopologyNodeTopologyRange
		return CustomTopologyNodeTopologyRange(self)

	@property
	def CustomTopologyRbLinks(self):
		"""An instance of the CustomTopologyRbLinks class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.customtopologyrblinks.CustomTopologyRbLinks)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.customtopologyrblinks import CustomTopologyRbLinks
		return CustomTopologyRbLinks(self)

	@property
	def CustomTopologySpbNodeTopologyRange(self):
		"""An instance of the CustomTopologySpbNodeTopologyRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.customtopologyspbnodetopologyrange.CustomTopologySpbNodeTopologyRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.customtopologyspbnodetopologyrange import CustomTopologySpbNodeTopologyRange
		return CustomTopologySpbNodeTopologyRange(self)

	@property
	def CustomTopologyUnicastMacRange(self):
		"""An instance of the CustomTopologyUnicastMacRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.customtopologyunicastmacrange.CustomTopologyUnicastMacRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.isis.customtopologyunicastmacrange import CustomTopologyUnicastMacRange
		return CustomTopologyUnicastMacRange(self)

	@property
	def CapRouterId(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('capRouterId')
	@CapRouterId.setter
	def CapRouterId(self, value):
		self._set_attribute('capRouterId', value)

	@property
	def EnableHostname(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableHostname')
	@EnableHostname.setter
	def EnableHostname(self, value):
		self._set_attribute('enableHostname', value)

	@property
	def Enabled(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def HostNamePrefix(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('hostNamePrefix')
	@HostNamePrefix.setter
	def HostNamePrefix(self, value):
		self._set_attribute('hostNamePrefix', value)

	@property
	def InterfaceMetric(self):
		"""NOT DEFINED

		Returns:
			number
		"""
		return self._get_attribute('interfaceMetric')
	@InterfaceMetric.setter
	def InterfaceMetric(self, value):
		self._set_attribute('interfaceMetric', value)

	@property
	def StartSysId(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('startSysId')
	@StartSysId.setter
	def StartSysId(self, value):
		self._set_attribute('startSysId', value)

	@property
	def SysIdInc(self):
		"""NOT DEFINED

		Returns:
			str
		"""
		return self._get_attribute('sysIdInc')
	@SysIdInc.setter
	def SysIdInc(self, value):
		self._set_attribute('sysIdInc', value)

	def update(self, CapRouterId=None, EnableHostname=None, Enabled=None, HostNamePrefix=None, InterfaceMetric=None, StartSysId=None, SysIdInc=None):
		"""Updates a child instance of customTopology on the server.

		Args:
			CapRouterId (str): NOT DEFINED
			EnableHostname (bool): NOT DEFINED
			Enabled (bool): NOT DEFINED
			HostNamePrefix (str): NOT DEFINED
			InterfaceMetric (number): NOT DEFINED
			StartSysId (str): NOT DEFINED
			SysIdInc (str): NOT DEFINED

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, CapRouterId=None, EnableHostname=None, Enabled=None, HostNamePrefix=None, InterfaceMetric=None, StartSysId=None, SysIdInc=None):
		"""Adds a new customTopology node on the server and retrieves it in this instance.

		Args:
			CapRouterId (str): NOT DEFINED
			EnableHostname (bool): NOT DEFINED
			Enabled (bool): NOT DEFINED
			HostNamePrefix (str): NOT DEFINED
			InterfaceMetric (number): NOT DEFINED
			StartSysId (str): NOT DEFINED
			SysIdInc (str): NOT DEFINED

		Returns:
			self: This instance with all currently retrieved customTopology data using find and the newly added customTopology data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the customTopology data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, CapRouterId=None, EnableHostname=None, Enabled=None, HostNamePrefix=None, InterfaceMetric=None, StartSysId=None, SysIdInc=None):
		"""Finds and retrieves customTopology data from the server.

		All named parameters support regex and can be used to selectively retrieve customTopology data from the server.
		By default the find method takes no parameters and will retrieve all customTopology data from the server.

		Args:
			CapRouterId (str): NOT DEFINED
			EnableHostname (bool): NOT DEFINED
			Enabled (bool): NOT DEFINED
			HostNamePrefix (str): NOT DEFINED
			InterfaceMetric (number): NOT DEFINED
			StartSysId (str): NOT DEFINED
			SysIdInc (str): NOT DEFINED

		Returns:
			self: This instance with matching customTopology data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of customTopology data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the customTopology data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Pppoxclient(Base):
	"""The Pppoxclient class encapsulates a user managed pppoxclient node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Pppoxclient property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'pppoxclient'

	def __init__(self, parent):
		super(Pppoxclient, self).__init__(parent)

	@property
	def Bfdv4Interface(self):
		"""An instance of the Bfdv4Interface class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bfdv4interface.Bfdv4Interface)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bfdv4interface import Bfdv4Interface
		return Bfdv4Interface(self)

	@property
	def Bfdv6Interface(self):
		"""An instance of the Bfdv6Interface class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bfdv6interface.Bfdv6Interface)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bfdv6interface import Bfdv6Interface
		return Bfdv6Interface(self)

	@property
	def BgpIpv4Peer(self):
		"""An instance of the BgpIpv4Peer class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bgpipv4peer.BgpIpv4Peer)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bgpipv4peer import BgpIpv4Peer
		return BgpIpv4Peer(self)

	@property
	def BgpIpv6Peer(self):
		"""An instance of the BgpIpv6Peer class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bgpipv6peer.BgpIpv6Peer)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.bgpipv6peer import BgpIpv6Peer
		return BgpIpv6Peer(self)

	@property
	def Connector(self):
		"""An instance of the Connector class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.connector.Connector)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.connector import Connector
		return Connector(self)

	@property
	def Dhcpv6client(self):
		"""An instance of the Dhcpv6client class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.dhcpv6client.Dhcpv6client)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.dhcpv6client import Dhcpv6client
		return Dhcpv6client(self)

	@property
	def EcpriRec(self):
		"""An instance of the EcpriRec class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ecprirec.EcpriRec)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ecprirec import EcpriRec
		return EcpriRec(self)

	@property
	def Ere(self):
		"""An instance of the Ere class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ere.Ere)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ere import Ere
		return Ere(self)

	@property
	def Geneve(self):
		"""An instance of the Geneve class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.geneve.Geneve)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.geneve import Geneve
		return Geneve(self)

	@property
	def IgmpHost(self):
		"""An instance of the IgmpHost class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.igmphost.IgmpHost)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.igmphost import IgmpHost
		return IgmpHost(self)

	@property
	def IgmpQuerier(self):
		"""An instance of the IgmpQuerier class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.igmpquerier.IgmpQuerier)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.igmpquerier import IgmpQuerier
		return IgmpQuerier(self)

	@property
	def MldHost(self):
		"""An instance of the MldHost class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.mldhost.MldHost)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.mldhost import MldHost
		return MldHost(self)

	@property
	def MldQuerier(self):
		"""An instance of the MldQuerier class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.mldquerier.MldQuerier)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.mldquerier import MldQuerier
		return MldQuerier(self)

	@property
	def MplsOam(self):
		"""An instance of the MplsOam class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.mplsoam.MplsOam)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.mplsoam import MplsOam
		return MplsOam(self)

	@property
	def NetconfClient(self):
		"""An instance of the NetconfClient class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.netconfclient.NetconfClient)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.netconfclient import NetconfClient
		return NetconfClient(self)

	@property
	def NetconfServer(self):
		"""An instance of the NetconfServer class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.netconfserver.NetconfServer)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.netconfserver import NetconfServer
		return NetconfServer(self)

	@property
	def Ospfv2(self):
		"""An instance of the Ospfv2 class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ospfv2.Ospfv2)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ospfv2 import Ospfv2
		return Ospfv2(self)

	@property
	def Ospfv3(self):
		"""An instance of the Ospfv3 class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ospfv3.Ospfv3)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.ospfv3 import Ospfv3
		return Ospfv3(self)

	@property
	def Pcc(self):
		"""An instance of the Pcc class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pcc.Pcc)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pcc import Pcc
		return Pcc(self)

	@property
	def Pce(self):
		"""An instance of the Pce class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pce.Pce)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pce import Pce
		return Pce(self)

	@property
	def PimV4Interface(self):
		"""An instance of the PimV4Interface class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pimv4interface.PimV4Interface)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pimv4interface import PimV4Interface
		return PimV4Interface(self)

	@property
	def PimV6Interface(self):
		"""An instance of the PimV6Interface class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pimv6interface.PimV6Interface)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.pimv6interface import PimV6Interface
		return PimV6Interface(self)

	@property
	def Tag(self):
		"""An instance of the Tag class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tag.Tag)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tag import Tag
		return Tag(self)

	@property
	def TlvProfile(self):
		"""An instance of the TlvProfile class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tlvprofile.tlvprofile.TlvProfile)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tlvprofile.tlvprofile import TlvProfile
		return TlvProfile(self)

	@property
	def Vxlan(self):
		"""An instance of the Vxlan class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.vxlan.Vxlan)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.vxlan import Vxlan
		return Vxlan(self)

	@property
	def AcMatchMac(self):
		"""?

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('acMatchMac')

	@property
	def AcMatchName(self):
		"""?

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('acMatchName')

	@property
	def AcOptions(self):
		"""Indicates PPPoE AC retrieval mode

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('acOptions')

	@property
	def ActualRateDownstream(self):
		"""This parameter specifies the value to be included in the vendor specific PPPoE tag. It is the actual downstream data rate (sub-option 0x81), in kbps.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('actualRateDownstream')

	@property
	def ActualRateUpstream(self):
		"""This parameter specifies the value to be included in the vendor specific PPPoE tag. It is the actual upstream data rate (sub-option 0x82), in kbps.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('actualRateUpstream')

	@property
	def AgentAccessAggregationCircuitId(self):
		"""The value to be inserted into the Agent Access-Aggregation-Circuit-ID-ASCII-Value field of the PPPoX tag.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('agentAccessAggregationCircuitId')

	@property
	def AgentCircuitId(self):
		"""The value to be inserted into the Agent Circuit ID field of the PPPoX tag.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('agentCircuitId')

	@property
	def AgentRemoteId(self):
		"""The value to be inserted into the Agent Remote ID field of the PPPoX tag.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('agentRemoteId')

	@property
	def AuthRetries(self):
		"""Number of PPP authentication retries

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('authRetries')

	@property
	def AuthTimeout(self):
		"""Timeout for PPP authentication, in seconds.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('authTimeout')

	@property
	def AuthType(self):
		"""The authentication type to use during link setup.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('authType')

	@property
	def ChapName(self):
		"""User name when CHAP Authentication is being used

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('chapName')

	@property
	def ChapSecret(self):
		"""Secret when CHAP Authentication is being used

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('chapSecret')

	@property
	def ClientDnsOptions(self):
		"""The client DNS options.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('clientDnsOptions')

	@property
	def ClientLocalIp(self):
		"""The requested IPv4 address.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('clientLocalIp')

	@property
	def ClientLocalIpv6Iid(self):
		"""The requested IPv6 Interface Identifier (IID).

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('clientLocalIpv6Iid')

	@property
	def ClientNcpOptions(self):
		"""The NCP configuration mode for IPv4 addressing.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('clientNcpOptions')

	@property
	def ClientNetmask(self):
		"""The netmask that the client will use with the assigned IP address.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('clientNetmask')

	@property
	def ClientNetmaskOptions(self):
		"""The client netmask option.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('clientNetmaskOptions')

	@property
	def ClientPrimaryDnsAddress(self):
		"""This is the primary DNS server address that the client requests from the server when the value of the Client DNS Options field is set to 'Request Primary only' or 'Request Primary and Secondary'.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('clientPrimaryDnsAddress')

	@property
	def ClientSecondaryDnsAddress(self):
		"""This is the secondary DNS server address that the client requests from the server when the value of the Client DNS Options field is set to 'Request Primary and Secondary'.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('clientSecondaryDnsAddress')

	@property
	def ClientSignalIWF(self):
		"""This parameter enables or disables the insertion of sub-option 0xFE (signaling of interworked sessions) into the DSL tag in PADI and PADR packets.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('clientSignalIWF')

	@property
	def ClientSignalLoopChar(self):
		"""This parameter enables or disables the insertion of sub-options 0x81 and 0x82 into the DSL tag in PADI and PADR packets.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('clientSignalLoopChar')

	@property
	def ClientSignalLoopEncapsulation(self):
		"""This parameter enables or disables the insertion of sub-option 0x90 into the DSL tag in PADI and PADR packets.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('clientSignalLoopEncapsulation')

	@property
	def ClientSignalLoopId(self):
		"""This parameter enables or disables the insertion of sub-options 0x01 , 0x02, 0x03 (Remote ID,Circuit ID and Access Aggregation Circuit ID) into the DSL tag in PADI and PADR packets.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('clientSignalLoopId')

	@property
	def ClientV6NcpOptions(self):
		"""The NCP configuration mode for IPv6 addressing.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('clientV6NcpOptions')

	@property
	def ClientWinsOptions(self):
		"""Specifies the mode in which WINS host addresses are configured.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('clientWinsOptions')

	@property
	def ClientWinsPrimaryAddress(self):
		"""Specifies the primary WINS address.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('clientWinsPrimaryAddress')

	@property
	def ClientWinsSecondaryAddress(self):
		"""Specifies the secondary WINS address.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('clientWinsSecondaryAddress')

	@property
	def ConnectedVia(self):
		"""DEPRECATED List of layers this layer used to connect to the wire

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('connectedVia')
	@ConnectedVia.setter
	def ConnectedVia(self, value):
		self._set_attribute('connectedVia', value)

	@property
	def Count(self):
		"""DEPRECATED Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DataLink(self):
		"""DEPRECATED A one-byte field included with sub-option 0x90.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('dataLink')

	@property
	def DescriptiveName(self):
		"""DEPRECATED Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def DiscoveredIpv4Addresses(self):
		"""DEPRECATED The discovered IPv4 addresses.

		Returns:
			list(str)
		"""
		return self._get_attribute('discoveredIpv4Addresses')

	@property
	def DiscoveredIpv6Addresses(self):
		"""DEPRECATED The discovered IPv6 addresses.

		Returns:
			list(str)
		"""
		return self._get_attribute('discoveredIpv6Addresses')

	@property
	def DiscoveredMacs(self):
		"""DEPRECATED The discovered remote MAC address.

		Returns:
			list(str)
		"""
		return self._get_attribute('discoveredMacs')

	@property
	def DiscoveredRemoteSessionIds(self):
		"""DEPRECATED Remote session ID.

		Returns:
			list(number)
		"""
		return self._get_attribute('discoveredRemoteSessionIds')

	@property
	def DiscoveredRemoteTunnelIds(self):
		"""DEPRECATED Remote tunnel ID.

		Returns:
			list(number)
		"""
		return self._get_attribute('discoveredRemoteTunnelIds')

	@property
	def DiscoveredSessionIds(self):
		"""DEPRECATED The negotiated session ID.

		Returns:
			list(number)
		"""
		return self._get_attribute('discoveredSessionIds')

	@property
	def DiscoveredTunnelIPs(self):
		"""DEPRECATED The discovered remote tunnel IP.

		Returns:
			list(str)
		"""
		return self._get_attribute('discoveredTunnelIPs')

	@property
	def DiscoveredTunnelIds(self):
		"""DEPRECATED The negotiated tunnel ID.

		Returns:
			list(number)
		"""
		return self._get_attribute('discoveredTunnelIds')

	@property
	def DomainList(self):
		"""DEPRECATED Configure domain group settings

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('domainList')

	@property
	def DslTypeTlv(self):
		"""DEPRECATED DSL Type to be advertised in PPPoE VSA Tag. For undefined DSL type user has to select User-defined DSL Type.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('dslTypeTlv')

	@property
	def EchoReqInterval(self):
		"""DEPRECATED Keep alive interval, in seconds

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('echoReqInterval')

	@property
	def EnableDomainGroups(self):
		"""DEPRECATED Enable domain groups

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableDomainGroups')

	@property
	def EnableEchoReq(self):
		"""DEPRECATED ?

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableEchoReq')

	@property
	def EnableEchoRsp(self):
		"""DEPRECATED ?

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableEchoRsp')

	@property
	def EnableHostUniq(self):
		"""DEPRECATED Enables PPPoE Host-Uniq tag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableHostUniq')

	@property
	def EnableMaxPayload(self):
		"""DEPRECATED Enables PPPoE Max Payload tag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableMaxPayload')

	@property
	def EnableRedial(self):
		"""DEPRECATED If checked, PPPoE redial is enabled

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableRedial')

	@property
	def Encaps1(self):
		"""DEPRECATED A one-byte field included with sub-option 0x90.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('encaps1')

	@property
	def Encaps2(self):
		"""DEPRECATED A one-byte field included with sub-option 0x90.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('encaps2')

	@property
	def EndpointDiscNegotiation(self):
		"""DEPRECATED Enable Endpoint Discriminator Negotiation

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('endpointDiscNegotiation')

	@property
	def EndpointDiscriminatorClass(self):
		"""DEPRECATED Endpoint Discriminator for PPP

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('endpointDiscriminatorClass')

	@property
	def Errors(self):
		"""DEPRECATED A list of errors that have occurred

		Returns:
			list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))
		"""
		return self._get_attribute('errors')

	@property
	def HostUniq(self):
		"""DEPRECATED Indicates Host-Uniq Tag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('hostUniq')

	@property
	def HostUniqLength(self):
		"""DEPRECATED Host-Uniq Length, in bytes

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('hostUniqLength')

	@property
	def LcpAccm(self):
		"""DEPRECATED Async-Control-Character-Map

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lcpAccm')

	@property
	def LcpEnableAccm(self):
		"""DEPRECATED Enable Async-Control-Character-Map

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lcpEnableAccm')

	@property
	def LcpMaxFailure(self):
		"""DEPRECATED Number of Configure-Nak packets sent without sending a Configure-Ack before assuming that configuration is not converging. Any further Configure-Nak packets for peer requested options are converted to Configure-Reject packets

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lcpMaxFailure')

	@property
	def LcpRetries(self):
		"""DEPRECATED Number of LCP retries

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lcpRetries')

	@property
	def LcpStartDelay(self):
		"""DEPRECATED Delay time in milliseconds to wait before sending LCP Config Request packet

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lcpStartDelay')

	@property
	def LcpTermRetries(self):
		"""DEPRECATED Number of LCP Termination Retries

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lcpTermRetries')

	@property
	def LcpTimeout(self):
		"""DEPRECATED Timeout for LCP phase, in seconds

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lcpTimeout')

	@property
	def MaxPayload(self):
		"""DEPRECATED Max Payload

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('maxPayload')

	@property
	def MlpppIPAddress(self):
		"""DEPRECATED The IP address used in the ML-PPP endpoint discriminator option of the LCP configure request sent by PPP clients

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('mlpppIPAddress')

	@property
	def MlpppMACAddress(self):
		"""DEPRECATED The MAC addresses are automatically derived from the local MAC address. An address in this class contains an IEEE 802.1 MAC address is canonical (802.3) format

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('mlpppMACAddress')

	@property
	def Mrru(self):
		"""DEPRECATED Max Receive Reconstructed Unit for PPP

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('mrru')

	@property
	def MrruNegotiation(self):
		"""DEPRECATED Enable MRRU Negotiation

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('mrruNegotiation')

	@property
	def MruNegotiation(self):
		"""DEPRECATED Enable MRU Negotiation

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('mruNegotiation')

	@property
	def Mtu(self):
		"""DEPRECATED Max Transmit Unit for PPP

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('mtu')

	@property
	def Multiplier(self):
		"""DEPRECATED Number of layer instances per parent instance (multiplier)

		Returns:
			number
		"""
		return self._get_attribute('multiplier')
	@Multiplier.setter
	def Multiplier(self, value):
		self._set_attribute('multiplier', value)

	@property
	def Name(self):
		"""DEPRECATED Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def NcpRetries(self):
		"""DEPRECATED Number of NCP retries

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ncpRetries')

	@property
	def NcpTimeout(self):
		"""DEPRECATED Timeout for NCP phase, in seconds

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ncpTimeout')

	@property
	def NcpType(self):
		"""DEPRECATED IP address type (IPv4 or IPv6) for Network Control Protocol

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ncpType')

	@property
	def PadiRetries(self):
		"""DEPRECATED Number of PADI Retries

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('padiRetries')

	@property
	def PadiTimeout(self):
		"""DEPRECATED Timeout for PADI no response, in seconds

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('padiTimeout')

	@property
	def PadrRetries(self):
		"""DEPRECATED Number of PADR Retries

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('padrRetries')

	@property
	def PadrTimeout(self):
		"""DEPRECATED Timeout for PADR no response, in seconds

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('padrTimeout')

	@property
	def PapPassword(self):
		"""DEPRECATED Password when PAP Authentication is being used

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('papPassword')

	@property
	def PapUser(self):
		"""DEPRECATED User name when PAP Authentication is being used

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('papUser')

	@property
	def PonTypeTlv(self):
		"""DEPRECATED PON Type to be advertised in PPPoE VSA Tag. For undefined PON type user has to select User-defined PON Type.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ponTypeTlv')

	@property
	def RedialMax(self):
		"""DEPRECATED Maximum number of PPPoE redials

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('redialMax')

	@property
	def RedialTimeout(self):
		"""DEPRECATED PPPoE redial timeout, in seconds

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('redialTimeout')

	@property
	def ServiceName(self):
		"""DEPRECATED Access Concentrator Service Name - this option is only available for PPP servers.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('serviceName')

	@property
	def ServiceOptions(self):
		"""DEPRECATED Indicates PPPoE service retrieval mode

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('serviceOptions')

	@property
	def SessionInfo(self):
		"""DEPRECATED Logs additional information about the session state

		Returns:
			list(str[cLS_CFG_REJ_AUTH|cLS_CHAP_PEER_DET_FAIL|cLS_CHAP_PEER_RESP_BAD|cLS_CODE_REJ_IPCP|cLS_CODE_REJ_IPV6CP|cLS_CODE_REJ_LCP|cLS_ERR_PPP_NO_BUF|cLS_ERR_PPP_SEND_PKT|cLS_LINK_DISABLE|cLS_LOC_IPADDR_BROADCAST|cLS_LOC_IPADDR_CLASS_E|cLS_LOC_IPADDR_INVAL_ACKS_0|cLS_LOC_IPADDR_INVAL_ACKS_DIFF|cLS_LOC_IPADDR_LOOPBACK|cLS_LOC_IPADDR_PEER_MATCH_LOC|cLS_LOC_IPADDR_PEER_NO_GIVE|cLS_LOC_IPADDR_PEER_NO_HELP|cLS_LOC_IPADDR_PEER_NO_TAKE|cLS_LOC_IPADDR_PEER_REJ|cLS_LOOPBACK_DETECT|cLS_NO_NCP|cLS_NONE|cLS_PAP_BAD_PASSWD|cLS_PEER_DISCONNECTED|cLS_PEER_DISCONNECTED_NEGO|cLS_PEER_IPADDR_MATCH_LOC|cLS_PEER_IPADDR_PEER_NO_SET|cLS_PPOE_AC_SYSTEM_ERROR|cLS_PPOE_GENERIC_ERROR|cLS_PPP_DISABLE|cLS_PPPOE_NO_HOST_UNIQ|cLS_PPPOE_PADI_TIMEOUT|cLS_PPPOE_PADO_TIMEOUT|cLS_PPPOE_PADR_TIMEOUT|cLS_PROTO_REJ_IPCP|cLS_PROTO_REJ_IPv6CP|cLS_TIMEOUT_CHAP_CHAL|cLS_TIMEOUT_CHAP_RESP|cLS_TIMEOUT_IPCP_CFG_REQ|cLS_TIMEOUT_IPV6CP_CFG_REQ|cLS_TIMEOUT_IPV6CP_RA|cLS_TIMEOUT_LCP_CFG_REQ|cLS_TIMEOUT_LCP_ECHO_REQ|cLS_TIMEOUT_PAP_AUTH_REQ|cLS_TUN_AUTH_FAILED|cLS_TUN_NO_RESOURCES|cLS_TUN_TIMEOUT_ICRQ|cLS_TUN_TIMEOUT_SCCRQ|cLS_TUN_VENDOR_SPECIFIC_ERR])
		"""
		return self._get_attribute('sessionInfo')

	@property
	def SessionStatus(self):
		"""DEPRECATED Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.

		Returns:
			list(str[down|notStarted|up])
		"""
		return self._get_attribute('sessionStatus')

	@property
	def StackedLayers(self):
		"""DEPRECATED List of secondary (many to one) child layer protocols

		Returns:
			list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])
		"""
		return self._get_attribute('stackedLayers')
	@StackedLayers.setter
	def StackedLayers(self, value):
		self._set_attribute('stackedLayers', value)

	@property
	def StateCounts(self):
		"""DEPRECATED A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up

		Returns:
			dict(total:number,notStarted:number,down:number,up:number)
		"""
		return self._get_attribute('stateCounts')

	@property
	def Status(self):
		"""DEPRECATED Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			str(configured|error|mixed|notStarted|started|starting|stopping)
		"""
		return self._get_attribute('status')

	@property
	def UnlimitedRedialAttempts(self):
		"""DEPRECATED If checked, PPPoE unlimited redial attempts is enabled

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('unlimitedRedialAttempts')

	@property
	def UserDefinedDslType(self):
		"""DEPRECATED User Defined DSL-Type Value.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('userDefinedDslType')

	@property
	def UserDefinedPonType(self):
		"""DEPRECATED User Defined PON-Type Value.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('userDefinedPonType')

	def update(self, ConnectedVia=None, Multiplier=None, Name=None, StackedLayers=None):
		"""Updates a child instance of pppoxclient on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, ConnectedVia=None, Multiplier=None, Name=None, StackedLayers=None):
		"""Adds a new pppoxclient node on the server and retrieves it in this instance.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols

		Returns:
			self: This instance with all currently retrieved pppoxclient data using find and the newly added pppoxclient data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the pppoxclient data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, ConnectedVia=None, Count=None, DescriptiveName=None, DiscoveredIpv4Addresses=None, DiscoveredIpv6Addresses=None, DiscoveredMacs=None, DiscoveredRemoteSessionIds=None, DiscoveredRemoteTunnelIds=None, DiscoveredSessionIds=None, DiscoveredTunnelIPs=None, DiscoveredTunnelIds=None, Errors=None, Multiplier=None, Name=None, SessionInfo=None, SessionStatus=None, StackedLayers=None, StateCounts=None, Status=None):
		"""Finds and retrieves pppoxclient data from the server.

		All named parameters support regex and can be used to selectively retrieve pppoxclient data from the server.
		By default the find method takes no parameters and will retrieve all pppoxclient data from the server.

		Args:
			ConnectedVia (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of layers this layer used to connect to the wire
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context
			DiscoveredIpv4Addresses (list(str)): The discovered IPv4 addresses.
			DiscoveredIpv6Addresses (list(str)): The discovered IPv6 addresses.
			DiscoveredMacs (list(str)): The discovered remote MAC address.
			DiscoveredRemoteSessionIds (list(number)): Remote session ID.
			DiscoveredRemoteTunnelIds (list(number)): Remote tunnel ID.
			DiscoveredSessionIds (list(number)): The negotiated session ID.
			DiscoveredTunnelIPs (list(str)): The discovered remote tunnel IP.
			DiscoveredTunnelIds (list(number)): The negotiated tunnel ID.
			Errors (list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))): A list of errors that have occurred
			Multiplier (number): Number of layer instances per parent instance (multiplier)
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			SessionInfo (list(str[cLS_CFG_REJ_AUTH|cLS_CHAP_PEER_DET_FAIL|cLS_CHAP_PEER_RESP_BAD|cLS_CODE_REJ_IPCP|cLS_CODE_REJ_IPV6CP|cLS_CODE_REJ_LCP|cLS_ERR_PPP_NO_BUF|cLS_ERR_PPP_SEND_PKT|cLS_LINK_DISABLE|cLS_LOC_IPADDR_BROADCAST|cLS_LOC_IPADDR_CLASS_E|cLS_LOC_IPADDR_INVAL_ACKS_0|cLS_LOC_IPADDR_INVAL_ACKS_DIFF|cLS_LOC_IPADDR_LOOPBACK|cLS_LOC_IPADDR_PEER_MATCH_LOC|cLS_LOC_IPADDR_PEER_NO_GIVE|cLS_LOC_IPADDR_PEER_NO_HELP|cLS_LOC_IPADDR_PEER_NO_TAKE|cLS_LOC_IPADDR_PEER_REJ|cLS_LOOPBACK_DETECT|cLS_NO_NCP|cLS_NONE|cLS_PAP_BAD_PASSWD|cLS_PEER_DISCONNECTED|cLS_PEER_DISCONNECTED_NEGO|cLS_PEER_IPADDR_MATCH_LOC|cLS_PEER_IPADDR_PEER_NO_SET|cLS_PPOE_AC_SYSTEM_ERROR|cLS_PPOE_GENERIC_ERROR|cLS_PPP_DISABLE|cLS_PPPOE_NO_HOST_UNIQ|cLS_PPPOE_PADI_TIMEOUT|cLS_PPPOE_PADO_TIMEOUT|cLS_PPPOE_PADR_TIMEOUT|cLS_PROTO_REJ_IPCP|cLS_PROTO_REJ_IPv6CP|cLS_TIMEOUT_CHAP_CHAL|cLS_TIMEOUT_CHAP_RESP|cLS_TIMEOUT_IPCP_CFG_REQ|cLS_TIMEOUT_IPV6CP_CFG_REQ|cLS_TIMEOUT_IPV6CP_RA|cLS_TIMEOUT_LCP_CFG_REQ|cLS_TIMEOUT_LCP_ECHO_REQ|cLS_TIMEOUT_PAP_AUTH_REQ|cLS_TUN_AUTH_FAILED|cLS_TUN_NO_RESOURCES|cLS_TUN_TIMEOUT_ICRQ|cLS_TUN_TIMEOUT_SCCRQ|cLS_TUN_VENDOR_SPECIFIC_ERR])): Logs additional information about the session state
			SessionStatus (list(str[down|notStarted|up])): Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.
			StackedLayers (list(str[None|/api/v1/sessions/1/ixnetwork/topology?deepchild=*])): List of secondary (many to one) child layer protocols
			StateCounts (dict(total:number,notStarted:number,down:number,up:number)): A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up
			Status (str(configured|error|mixed|notStarted|started|starting|stopping)): Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			self: This instance with matching pppoxclient data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of pppoxclient data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the pppoxclient data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, AcMatchMac=None, AcMatchName=None, AcOptions=None, ActualRateDownstream=None, ActualRateUpstream=None, AgentAccessAggregationCircuitId=None, AgentCircuitId=None, AgentRemoteId=None, AuthRetries=None, AuthTimeout=None, AuthType=None, ChapName=None, ChapSecret=None, ClientDnsOptions=None, ClientLocalIp=None, ClientLocalIpv6Iid=None, ClientNcpOptions=None, ClientNetmask=None, ClientNetmaskOptions=None, ClientPrimaryDnsAddress=None, ClientSecondaryDnsAddress=None, ClientSignalIWF=None, ClientSignalLoopChar=None, ClientSignalLoopEncapsulation=None, ClientSignalLoopId=None, ClientV6NcpOptions=None, ClientWinsOptions=None, ClientWinsPrimaryAddress=None, ClientWinsSecondaryAddress=None, DataLink=None, DomainList=None, DslTypeTlv=None, EchoReqInterval=None, EnableDomainGroups=None, EnableEchoReq=None, EnableEchoRsp=None, EnableHostUniq=None, EnableMaxPayload=None, EnableRedial=None, Encaps1=None, Encaps2=None, EndpointDiscNegotiation=None, EndpointDiscriminatorClass=None, HostUniq=None, HostUniqLength=None, LcpAccm=None, LcpEnableAccm=None, LcpMaxFailure=None, LcpRetries=None, LcpStartDelay=None, LcpTermRetries=None, LcpTimeout=None, MaxPayload=None, MlpppIPAddress=None, MlpppMACAddress=None, Mrru=None, MrruNegotiation=None, MruNegotiation=None, Mtu=None, NcpRetries=None, NcpTimeout=None, NcpType=None, PadiRetries=None, PadiTimeout=None, PadrRetries=None, PadrTimeout=None, PapPassword=None, PapUser=None, PonTypeTlv=None, RedialMax=None, RedialTimeout=None, ServiceName=None, ServiceOptions=None, UnlimitedRedialAttempts=None, UserDefinedDslType=None, UserDefinedPonType=None):
		"""Base class infrastructure that gets a list of pppoxclient device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			AcMatchMac (str): optional regex of acMatchMac
			AcMatchName (str): optional regex of acMatchName
			AcOptions (str): optional regex of acOptions
			ActualRateDownstream (str): optional regex of actualRateDownstream
			ActualRateUpstream (str): optional regex of actualRateUpstream
			AgentAccessAggregationCircuitId (str): optional regex of agentAccessAggregationCircuitId
			AgentCircuitId (str): optional regex of agentCircuitId
			AgentRemoteId (str): optional regex of agentRemoteId
			AuthRetries (str): optional regex of authRetries
			AuthTimeout (str): optional regex of authTimeout
			AuthType (str): optional regex of authType
			ChapName (str): optional regex of chapName
			ChapSecret (str): optional regex of chapSecret
			ClientDnsOptions (str): optional regex of clientDnsOptions
			ClientLocalIp (str): optional regex of clientLocalIp
			ClientLocalIpv6Iid (str): optional regex of clientLocalIpv6Iid
			ClientNcpOptions (str): optional regex of clientNcpOptions
			ClientNetmask (str): optional regex of clientNetmask
			ClientNetmaskOptions (str): optional regex of clientNetmaskOptions
			ClientPrimaryDnsAddress (str): optional regex of clientPrimaryDnsAddress
			ClientSecondaryDnsAddress (str): optional regex of clientSecondaryDnsAddress
			ClientSignalIWF (str): optional regex of clientSignalIWF
			ClientSignalLoopChar (str): optional regex of clientSignalLoopChar
			ClientSignalLoopEncapsulation (str): optional regex of clientSignalLoopEncapsulation
			ClientSignalLoopId (str): optional regex of clientSignalLoopId
			ClientV6NcpOptions (str): optional regex of clientV6NcpOptions
			ClientWinsOptions (str): optional regex of clientWinsOptions
			ClientWinsPrimaryAddress (str): optional regex of clientWinsPrimaryAddress
			ClientWinsSecondaryAddress (str): optional regex of clientWinsSecondaryAddress
			DataLink (str): optional regex of dataLink
			DomainList (str): optional regex of domainList
			DslTypeTlv (str): optional regex of dslTypeTlv
			EchoReqInterval (str): optional regex of echoReqInterval
			EnableDomainGroups (str): optional regex of enableDomainGroups
			EnableEchoReq (str): optional regex of enableEchoReq
			EnableEchoRsp (str): optional regex of enableEchoRsp
			EnableHostUniq (str): optional regex of enableHostUniq
			EnableMaxPayload (str): optional regex of enableMaxPayload
			EnableRedial (str): optional regex of enableRedial
			Encaps1 (str): optional regex of encaps1
			Encaps2 (str): optional regex of encaps2
			EndpointDiscNegotiation (str): optional regex of endpointDiscNegotiation
			EndpointDiscriminatorClass (str): optional regex of endpointDiscriminatorClass
			HostUniq (str): optional regex of hostUniq
			HostUniqLength (str): optional regex of hostUniqLength
			LcpAccm (str): optional regex of lcpAccm
			LcpEnableAccm (str): optional regex of lcpEnableAccm
			LcpMaxFailure (str): optional regex of lcpMaxFailure
			LcpRetries (str): optional regex of lcpRetries
			LcpStartDelay (str): optional regex of lcpStartDelay
			LcpTermRetries (str): optional regex of lcpTermRetries
			LcpTimeout (str): optional regex of lcpTimeout
			MaxPayload (str): optional regex of maxPayload
			MlpppIPAddress (str): optional regex of mlpppIPAddress
			MlpppMACAddress (str): optional regex of mlpppMACAddress
			Mrru (str): optional regex of mrru
			MrruNegotiation (str): optional regex of mrruNegotiation
			MruNegotiation (str): optional regex of mruNegotiation
			Mtu (str): optional regex of mtu
			NcpRetries (str): optional regex of ncpRetries
			NcpTimeout (str): optional regex of ncpTimeout
			NcpType (str): optional regex of ncpType
			PadiRetries (str): optional regex of padiRetries
			PadiTimeout (str): optional regex of padiTimeout
			PadrRetries (str): optional regex of padrRetries
			PadrTimeout (str): optional regex of padrTimeout
			PapPassword (str): optional regex of papPassword
			PapUser (str): optional regex of papUser
			PonTypeTlv (str): optional regex of ponTypeTlv
			RedialMax (str): optional regex of redialMax
			RedialTimeout (str): optional regex of redialTimeout
			ServiceName (str): optional regex of serviceName
			ServiceOptions (str): optional regex of serviceOptions
			UnlimitedRedialAttempts (str): optional regex of unlimitedRedialAttempts
			UserDefinedDslType (str): optional regex of userDefinedDslType
			UserDefinedPonType (str): optional regex of userDefinedPonType

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def CloseIpcp(self, *args, **kwargs):
		"""Executes the closeIpcp operation on the server.

		Close IPCP for selected PPPoX items.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		closeIpcp()list

			Returns:
				list(dict(port:str[None|/api/v1/sessions/1/ixnetwork/vport],isSuccess:bool,data:str)): The return value is an array of structures where each structure consists of a /vport object reference, the success of the operation and the returned data of the operation for that /vport. This exec is not asynchronous.

		closeIpcp(SessionIndices:list)list
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

			Returns:
				list(dict(port:str[None|/api/v1/sessions/1/ixnetwork/vport],isSuccess:bool,data:str)): The return value is an array of structures where each structure consists of a /vport object reference, the success of the operation and the returned data of the operation for that /vport. This exec is not asynchronous.

		closeIpcp(SessionIndices:string)list
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

			Returns:
				list(dict(port:str[None|/api/v1/sessions/1/ixnetwork/vport],isSuccess:bool,data:str)): The return value is an array of structures where each structure consists of a /vport object reference, the success of the operation and the returned data of the operation for that /vport. This exec is not asynchronous.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('closeIpcp', payload=payload, response_object=None)

	def CloseIpv6cp(self, *args, **kwargs):
		"""Executes the closeIpv6cp operation on the server.

		Close IPv6CP for selected PPPoX items.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		closeIpv6cp()list

			Returns:
				list(dict(port:str[None|/api/v1/sessions/1/ixnetwork/vport],isSuccess:bool,data:str)): The return value is an array of structures where each structure consists of a /vport object reference, the success of the operation and the returned data of the operation for that /vport. This exec is not asynchronous.

		closeIpv6cp(SessionIndices:list)list
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

			Returns:
				list(dict(port:str[None|/api/v1/sessions/1/ixnetwork/vport],isSuccess:bool,data:str)): The return value is an array of structures where each structure consists of a /vport object reference, the success of the operation and the returned data of the operation for that /vport. This exec is not asynchronous.

		closeIpv6cp(SessionIndices:string)list
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

			Returns:
				list(dict(port:str[None|/api/v1/sessions/1/ixnetwork/vport],isSuccess:bool,data:str)): The return value is an array of structures where each structure consists of a /vport object reference, the success of the operation and the returned data of the operation for that /vport. This exec is not asynchronous.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('closeIpv6cp', payload=payload, response_object=None)

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def OpenIpcp(self, *args, **kwargs):
		"""Executes the openIpcp operation on the server.

		Open IPCP for selected PPPoX items.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		openIpcp()list

			Returns:
				list(dict(port:str[None|/api/v1/sessions/1/ixnetwork/vport],isSuccess:bool,data:str)): The return value is an array of structures where each structure consists of a /vport object reference, the success of the operation and the returned data of the operation for that /vport. This exec is not asynchronous.

		openIpcp(SessionIndices:list)list
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

			Returns:
				list(dict(port:str[None|/api/v1/sessions/1/ixnetwork/vport],isSuccess:bool,data:str)): The return value is an array of structures where each structure consists of a /vport object reference, the success of the operation and the returned data of the operation for that /vport. This exec is not asynchronous.

		openIpcp(SessionIndices:string)list
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

			Returns:
				list(dict(port:str[None|/api/v1/sessions/1/ixnetwork/vport],isSuccess:bool,data:str)): The return value is an array of structures where each structure consists of a /vport object reference, the success of the operation and the returned data of the operation for that /vport. This exec is not asynchronous.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('openIpcp', payload=payload, response_object=None)

	def OpenIpv6cp(self, *args, **kwargs):
		"""Executes the openIpv6cp operation on the server.

		Open IPv6CP for selected PPPoX items.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		openIpv6cp()list

			Returns:
				list(dict(port:str[None|/api/v1/sessions/1/ixnetwork/vport],isSuccess:bool,data:str)): The return value is an array of structures where each structure consists of a /vport object reference, the success of the operation and the returned data of the operation for that /vport. This exec is not asynchronous.

		openIpv6cp(SessionIndices:list)list
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

			Returns:
				list(dict(port:str[None|/api/v1/sessions/1/ixnetwork/vport],isSuccess:bool,data:str)): The return value is an array of structures where each structure consists of a /vport object reference, the success of the operation and the returned data of the operation for that /vport. This exec is not asynchronous.

		openIpv6cp(SessionIndices:string)list
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

			Returns:
				list(dict(port:str[None|/api/v1/sessions/1/ixnetwork/vport],isSuccess:bool,data:str)): The return value is an array of structures where each structure consists of a /vport object reference, the success of the operation and the returned data of the operation for that /vport. This exec is not asynchronous.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('openIpv6cp', payload=payload, response_object=None)

	def RestartDown(self, *args, **kwargs):
		"""Executes the restartDown operation on the server.

		Stop and start interfaces and sessions that are in Down state.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		restartDown()

		restartDown(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		restartDown(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('restartDown', payload=payload, response_object=None)

	def SendPing(self, *args, **kwargs):
		"""Executes the sendPing operation on the server.

		Send Ping IPv4 for selected PPPoX items.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendPing(DestIp:string)list
			Args:
				args[0] is DestIp (str): This parameter requires a destIp of type kString

			Returns:
				list(dict(port:str[None|/api/v1/sessions/1/ixnetwork/vport],isSuccess:bool,data:str)): The return value is an array of structures where each structure consists of a /vport object reference, the success of the operation and the returned data of the operation for that /vport. This exec is not asynchronous.

		sendPing(DestIp:string, SessionIndices:list)list
			Args:
				args[0] is DestIp (str): This parameter requires a destIp of type kString
				args[1] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

			Returns:
				list(dict(port:str[None|/api/v1/sessions/1/ixnetwork/vport],isSuccess:bool,data:str)): The return value is an array of structures where each structure consists of a /vport object reference, the success of the operation and the returned data of the operation for that /vport. This exec is not asynchronous.

		sendPing(SessionIndices:string, DestIp:string)list
			Args:
				args[0] is SessionIndices (str): This parameter requires a destIp of type kString
				args[1] is DestIp (str): This parameter requires a string of session numbers 1-4;6;7-12

			Returns:
				list(dict(port:str[None|/api/v1/sessions/1/ixnetwork/vport],isSuccess:bool,data:str)): The return value is an array of structures where each structure consists of a /vport object reference, the success of the operation and the returned data of the operation for that /vport. This exec is not asynchronous.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendPing', payload=payload, response_object=None)

	def SendPing6(self, *args, **kwargs):
		"""Executes the sendPing6 operation on the server.

		Send Ping IPv6 for selected PPPoX items.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		sendPing6(DestIp:string)list
			Args:
				args[0] is DestIp (str): This parameter requires a destIp of type kString

			Returns:
				list(dict(port:str[None|/api/v1/sessions/1/ixnetwork/vport],isSuccess:bool,data:str)): The return value is an array of structures where each structure consists of a /vport object reference, the success of the operation and the returned data of the operation for that /vport. This exec is not asynchronous.

		sendPing6(DestIp:string, SessionIndices:list)list
			Args:
				args[0] is DestIp (str): This parameter requires a destIp of type kString
				args[1] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

			Returns:
				list(dict(port:str[None|/api/v1/sessions/1/ixnetwork/vport],isSuccess:bool,data:str)): The return value is an array of structures where each structure consists of a /vport object reference, the success of the operation and the returned data of the operation for that /vport. This exec is not asynchronous.

		sendPing6(SessionIndices:string, DestIp:string)list
			Args:
				args[0] is SessionIndices (str): This parameter requires a destIp of type kString
				args[1] is DestIp (str): This parameter requires a string of session numbers 1-4;6;7-12

			Returns:
				list(dict(port:str[None|/api/v1/sessions/1/ixnetwork/vport],isSuccess:bool,data:str)): The return value is an array of structures where each structure consists of a /vport object reference, the success of the operation and the returned data of the operation for that /vport. This exec is not asynchronous.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('sendPing6', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Start selected protocols.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		start(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self, *args, **kwargs):
		"""Executes the stop operation on the server.

		Stop selected protocols.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stop()

		stop(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stop(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stop', payload=payload, response_object=None)
